---
name: r.topidx
description: Creates a topographic index (wetness index) raster map from an elevation raster map.
keywords: [ raster, hydrology, wetness, topographic index ]
---

# r.topidx

Creates a topographic index (wetness index) raster map from an elevation raster map.

=== "Command line"

    **r.topidx**
    **input**=*name*
    **output**=*name*
    [**--overwrite**]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    r.topidx input=name output=name
    ```

=== "Python (grass.script)"

    *grass.script.run_command*("***r.topidx***",
        **input**,
        **output**,
        **overwrite**=*False*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.run_command("r.topidx", input="name", output="name")
    ```

## Parameters

=== "Command line"

    **input**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input elevation raster map  
    **output**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output topographic index raster map  
    **--overwrite**  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **input** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input elevation raster map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, raster, *name*  
    **output** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output topographic index raster map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: output, raster, *name*  
    **overwrite**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

*r.topidx* creates topographic index (wetness index), ln(a/tan(beta)),
map from elevation map where

- a: the area of the hillslope per unit contour length that drains
  through any point,
- tan(beta): the local surface topographic slope (delta vertical) /
  (delta horizontal).

Input maps may have NULL values. For example, if you have a raster mask
set for a watershed (using basin map from *r.water.outlet*), the
following command will create a masked elevation map (belev):

```sh
r.mapcalc "belev = if(isnull(basin), basin, elev)"
```

*r.stats -Anc* prints out averaged statistics for topographic index.

Lat/long projects are not supported. If data is not projected, please
create a new project with a projected coordinate reference system and
reproject the data there. Please run *r.topidx* from that project.

## EXAMPLE

Running the command below will generate the topographic index map shown
in the figure:

```sh
g.region raster=elevation -p
r.topidx input=elevation output=topidx_elevation
```

![r.topidx example](r_topidx.png)  
*Figure: topographic index map derived from elevation map*

## REFERENCES

Cho, H., 2000. GIS Hydrological Modeling System by Using Programming
Interface of GRASS. Master's Thesis, Department of Civil Engineering,
Kyungpook National University, Korea.

Moore, I.D., R.B. Grayson, and A.R. Ladson, 1991. Digital Terrain
Modeling: A Review of Hydrological, Geomorphological, and Biological
Applications. Hydrological Processes 5:3-30.

## SEE ALSO

*[r.topmodel](r.topmodel.md), [r.water.outlet](r.water.outlet.md),
[r.mapcalc](r.mapcalc.md)*  
[Known issues](http://idea.isnew.info/r.topidx.html)

## AUTHORS

[Huidae Cho](mailto:grass4u@gmail-com)  
Hydro Laboratory, Kyungpook National University, South Korea

Based on GRIDATB.FOR by Keith Beven.

## SOURCE CODE

Available at: [r.topidx source code](https://github.com/OSGeo/grass/tree/main/raster/r.topidx)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.topidx))  
Latest change: Thursday Feb 13 11:55:34 2025 in commit [ffc0b8c](https://github.com/OSGeo/grass/commit/ffc0b8c9c71c2c78415bb0db0bd9d7daea963353)
